# Changelog

* *1.2.0** (2023-10-04)
  * Added Python 3.12 support
  * Updated internal linter packages

* *1.1.6** (2023-09-08)
  * Metadata update via ambient package updater

* *1.1.5** (2023-09-08)
  * Metadata update via ambient package updater
  * Cleaned up test matrix

* **1.1.4** (2023-08-31)
  * Fixed downloads badge

* **1.1.3** (2023-08-31)
  * Improved type-hinting for constructor of `BaseEmailServiceFactory` and `BaseEmailService`

* **1.1.2** (2023-08-14)
  * Updated linters and add more strict linting rules

* **1.1.1** (2023-05-10)
  * Updated readme "maintenance" section
  * Updated package linters
  * Added release scripts for windows and UNIX

* **1.1.0** (2023-05-04)
  * Support for Django 4.2 added

* **1.0.2** (2023-05-04)
  * Updated documentation

* **1.0.1** (2023-05-03)
  * Added missing translations
  * Updated documentation

* **1.0.0** (2023-05-01)
  * Release as a separate package at PyPI (was before a part of [ai-django-core](https://pypi.org/project/ai-django-core/))
